/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Monopsony power and wages: Evidence from the introduction of serfdom in Denmark  
by  Kathrin Gary, Peter Sandholt Jensen, Mats Olsson, Cristina Victoria Radu,
Battista Severgnini and Paul Sharp (2022)

The following do file replicates Figures reported both in the main text (p.46-53) and in the appendix. 

Before launching the file, please 

a) read the file readme.docx/readme.pdf contained in the zipped file

c) write your working directory in line 22 of this do file.

Launching this file, replicates all the results in Stata. As soon as the working directory is set, the code for each table can be run separately. 

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

*Packages needed to run this file: coefplot and lean1

*change working directory for location of data

cd "[insert directory with dta files]"

*set scheme plotplainblind
set scheme lean1

*Figure 1: Average (log) wages for farmhands and other occupations, 1705-1799

use "farmhands.dta", clear 

gen wagedif= mean_farmhands- mean_others

label var year1 year
label var mean_farmhands farmhands
label var mean_others control
label var wagedif differential 

gen avg_wage_dif=0

replace avg_wage_dif=0.40056 if year1 >=1705 & year1 < 1733

replace avg_wage_dif=0.0839973 if year1 >=1733 & year1 < 1742

replace avg_wage_dif=-0.1178026 if year1 >=1742 & year1 < 1764

replace avg_wage_dif= 0.0378191  if year1 >=1764 & year1 < 1788

replace avg_wage_dif=0.0388421 if year1 >=1788 & year1 <= 1799

label var avg_wage "average differential" 

line wagedif year1 if year1>=1705 & year1<=1799 || line mean_farmhands year1 if year1>=1705 & year1<=1799 || line mean_others year1 if year1>=1705 & year1<=1799 || line avg_wage_dif year1 if year1>=1705 & year1<=1799,  xline(1730 1733 1742 1764 1788, lstyle(grid))

*Figure 2: Average (log) barley prices and farmahnd wages

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen logwage = ln(norm_wage_rate)

*Load price data

merge m:1 manor year1 using "barley_prices_2.dta"

drop _merge

gen logpricebarley=ln(Pris_per_enhed)

bysort year1: egen mean_farmhands =mean(logwage) if unskilled==1
bysort year1: egen mean_logpricebarley = mean(logpricebarley) 

label var year1 year

label var mean_farmhands farmhands

label var mean_logpricebarley "barley price"

line mean_farmhands year1 if year1>=1705 || line mean_logpricebarley year1 if year1>=1705,  xline(1733 1742 1764 1788, lstyle(grid))

*Figure 3: Comparison of Farmhands and unskilled workers from Scania

use "Scania.dta", clear

gen Denmark=0

replace Denmark=1 if region =="Funen"|region=="Jutland"|region=="Zealand"

drop if region=="hasnone"

gen serfdom=year>=1733

gen serfdom_DK=serfdom*Denmark

gen logwage=ln(wagerate)

gen wagerate2=wagerate/96

gen logwage2=ln(wagerate2)

*Skilling measures

gen wagerateDK_2= Denmark*wagerate

gen wagerateSC_2=(1-Denmark)*wagerate*16*4*6 

gen wagerate3=wagerateDK_2+wagerateSC_2

merge m:m year Denmark using "EXRdata.dta"

gen wagerateDK= Denmark*wagerate/96

gen wagerateSC=exr*(1-Denmark)*wagerate/100

gen wagerateCR=wagerateDK+wagerateSC

gen wagerateSC2=(1-Denmark)*wagerate

gen wagerateCR2=wagerateDK+wagerateSC2

gen rwage=wagerateCR2/price_normal

gen logwageCR=ln(wagerateCR)

gen logwageCR2=ln(rwage)

gen logwage3=ln(wagerate3)

gen unskilled1=(HISCO==62105)

gen unskilled2=(HISCO==99910)

gen unskilled3=(HISCO==99920)

gen unskilled=(HISCO==62105 | HISCO==99910 | HISCO==99920)

bysort year: egen mean_Denmark =mean(logwage3) if Denmark==1 & unskilled==1
bysort year: egen mean_Sweden = mean(logwage3) if Denmark==0 & unskilled==1

label var mean_Denmark Denmark

label var mean_Sweden Scania

line mean_Denmark year if year>=1705 & year<=1799 || line mean_Sweden year if year>=1705 & year<=1799,  xline(1730 1733 1742 1764 1788, lstyle(grid))

*Figure 4: Comparison of average log real wages in Denmark and Scania, 1705-1799

use "Scania.dta", clear

gen Denmark=0

replace Denmark=1 if region =="Funen"|region=="Jutland"|region=="Zealand"

drop if region=="hasnone"

gen serfdom=year>=1733

gen serfdom_DK=serfdom*Denmark

gen logwage=ln(wagerate)

gen wagerate2=wagerate/96

gen logwage2=ln(wagerate2)

*Skilling measures

gen wagerateDK_2= Denmark*wagerate

gen wagerateSC_2=(1-Denmark)*wagerate*16*4*6 

gen wagerate3=wagerateDK_2+wagerateSC_2

merge m:m year Denmark using "EXRdata.dta"

gen wagerateDK= Denmark*wagerate/96

gen wagerateSC=exr*(1-Denmark)*wagerate/100

gen wagerateCR=wagerateDK+wagerateSC

gen wagerateSC2=(1-Denmark)*wagerate

gen wagerateCR2=wagerateDK+wagerateSC2

gen rwage=wagerateCR2/price_normal

gen logwageCR=ln(wagerateCR)

gen logwageCR2=ln(rwage)

gen logwage3=ln(wagerate3)

gen unskilled1=(HISCO==62105)

gen unskilled2=(HISCO==99910)

gen unskilled3=(HISCO==99920)

gen unskilled=(HISCO==62105 | HISCO==99910 | HISCO==99920)

bysort year: egen mean_Denmark2 =mean(logwageCR2) if Denmark==1 & unskilled==1
bysort year: egen mean_Sweden2 = mean(logwageCR2) if Denmark==0 & unskilled==1

label var mean_Denmark2 Denmark

label var mean_Sweden2 Scania

line mean_Denmark2 year if year>=1705 & year<=1799 || line mean_Sweden2 year if year>=1705 & year<=1799,  xline(1730 1733 1742 1764 1788, lstyle(grid))

*Figure 5- generated with GIS software

*Figure 6: Event study for the introduction of serfdom, coefficient on farmhands multiplied by time dummies

use "out2corr5.dta", clear

gen p5=(year1>=1800)

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen logwage = ln(norm_wage_rate)


*five year dummies

gen t1=(year1>1704 & year1 <1710)

gen t2=(year1>1709 & year1 <1715)

gen t3=(year1>1714 & year1 <1720)

gen t4=(year1>1719 & year1 <1725)

gen t5=(year1>1724 & year1 <1733)

gen t6=(year1>1732 & year1 <1735)

gen t7=(year1>1734 & year1 <1740)

gen t8=(year1>1739 & year1 <1745)

gen t9=(year1>1744 & year1 <1750)

gen t10=(year1>1749 & year1 <1755)

gen t11=(year1>1754 & year1 <1760)

gen t12=(year1>1759 & year1 <1765)

gen t13=(year1>1764 & year1 <1770)

gen t14=(year1>1769 & year1 <1775)

gen t15=(year1>1774 & year1 <1780)

gen t16=(year1>1779 & year1 <1785)

gen t17=(year1>1784 & year1 <1790)

gen t18=(year1>1789 & year1 <1795)

gen t19=(year1>1794 & year1 <1800)

gen unskilled1710=t2*unskilled

gen unskilled1715=t3*unskilled

gen unskilled1720=t4*unskilled

gen unskilled1725=t5*unskilled

gen unskilled1733=t6*unskilled

gen unskilled1735=t7*unskilled

gen unskilled1740=t8*unskilled

gen unskilled1745=t9*unskilled

gen unskilled1750=t10*unskilled

gen unskilled1755=t11*unskilled

gen unskilled1760=t12*unskilled

gen unskilled1765=t13*unskilled

gen unskilled1770=t14*unskilled

gen unskilled1775=t15*unskilled

gen unskilled1780=t16*unskilled

gen unskilled1785=t17*unskilled

gen unskilled1790=t18*unskilled

gen unskilled1795=t19*unskilled


xi: reg logwage unskilled1710 unskilled1715 unskilled1720 unskilled1725 unskilled1733 unskilled1735 unskilled1740 unskilled1745 unskilled1750 unskilled1755 unskilled1760 unskilled1765 unskilled1770 unskilled1775 unskilled1780 unskilled1785 unskilled1790 unskilled1795 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

estimates store flex_serf

coefplot (flex_serf, label(event study)) , xsize(6.4) xtitle("Year") ytitle("Coefficients") omitted vertical msymbol(s) mfcolor(white) yline(0) xline(5) rename(unskilled*=" ") keep(unskilled*)

*Figure 7: Urban-rural wages differences, 1731-1799

use "urban_rural.dta", clear

drop if year<1731

label var year1 year
label var mean_farmhands farmhands
label var mean_urban "urban workers"

line mean_farmhands year1 if year1>=1730 & year1<=1799 || line mean_urban year1 if year1>=1730 & year1<=1799,  xline(1733 1742 1764 1788, lstyle(grid))

*Figure 8: Event study for the introduction of serfdom, coefficient on farmhands multiplied by time dummies

clear

use "Scania.dta"

gen Denmark=0

replace Denmark=1 if region =="Funen"|region=="Jutland"|region=="Zealand"

drop if region=="hasnone"

gen serfdom=year>=1733

gen serfdom_DK=serfdom*Denmark

gen logwage=ln(wagerate)

gen wagerate2=wagerate/96

gen logwage2=ln(wagerate2)

*Skilling measures

gen wagerateDK_2= Denmark*wagerate

gen wagerateSC_2=(1-Denmark)*wagerate*16*4*6 

gen wagerate3=wagerateDK_2+wagerateSC_2

merge m:m year Denmark using "EXRdata.dta"

gen wagerateDK= Denmark*wagerate/96

gen wagerateSC=exr*(1-Denmark)*wagerate/100

gen wagerateCR=wagerateDK+wagerateSC

gen wagerateSC2=(1-Denmark)*wagerate

gen wagerateCR2=wagerateDK+wagerateSC2

gen rwage=wagerateCR2/price_normal

gen logwageCR=ln(wagerateCR)

gen logwageCR2=ln(rwage)

gen logwage3=ln(wagerate3)

gen unskilled1=(HISCO==62105)

gen unskilled2=(HISCO==99910)

gen unskilled3=(HISCO==99920)

gen unskilled=(HISCO==62105 | HISCO==99910 | HISCO==99920)

*five year dummies

gen t1=(year>1704 & year <1710)

gen t2=(year>1709 & year <1715)

gen t3=(year>1714 & year <1720)

gen t4=(year>1719 & year <1725)

gen t5=(year>1724 & year <1733)

gen t6=(year>1732 & year <1735)

gen t7=(year>1734 & year <1740)

gen t8=(year>1739 & year <1745)

gen t9=(year>1744 & year <1750)

gen t10=(year>1749 & year <1755)

gen t11=(year>1754 & year <1760)

gen t12=(year>1759 & year <1765)

gen t13=(year>1764 & year <1770)

gen t14=(year>1769 & year <1775)

gen t15=(year>1774 & year <1780)

gen t16=(year>1779 & year <1785)

gen t17=(year>1784 & year <1790)

gen t18=(year>1789 & year <1795)

gen t19=(year>1794 & year <1800)

gen Denmark1710=t2*Denmark

gen Denmark1715=t3*Denmark

gen Denmark1720=t4*Denmark

gen Denmark1725=t5*Denmark

gen Denmark1733=t6*Denmark

gen Denmark1735=t7*Denmark

gen Denmark1740=t8*Denmark

gen Denmark1745=t9*Denmark

gen Denmark1750=t10*Denmark

gen Denmark1755=t11*Denmark

gen Denmark1760=t12*Denmark

gen Denmark1765=t13*Denmark

gen Denmark1770=t14*Denmark

gen Denmark1775=t15*Denmark

gen Denmark1780=t16*Denmark

gen Denmark1785=t17*Denmark

gen Denmark1790=t18*Denmark

gen Denmark1795=t19*Denmark

xi: reg logwage Denmark1710 Denmark1715 Denmark1720 Denmark1725 Denmark1733 Denmark1735 Denmark1740 Denmark1745 Denmark1750 Denmark1755 Denmark1760 Denmark1765 Denmark1770 Denmark1775 Denmark1780 Denmark1785 Denmark1790 Denmark1795 i.year i.gender i.region if year> 1704 & year <1800 & unskilled==1, cluster(placename)

estimates store flex_serf

coefplot (flex_serf, label(event study)) , xsize(6.4) xtitle("Year") ytitle("Coefficients") omitted vertical msymbol(s) mfcolor(white) yline(0) xline(5) rename(Denmark*=" ") keep(Denmark*)


*Appendix

*Figure A1: Price of rye and farmhand wages, 1705-1799

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen logwage = ln(norm_wage_rate)

*Load price data

merge m:1 manor year1 using "rye_prices_2.dta"

drop _merge

gen logpricerye=ln(price_rye)

bysort year1: egen mean_farmhands =mean(logwage) if unskilled==1
bysort year1: egen mean_logpricerye = mean(logpricerye) 
 
label var year1 year

label var mean_farmhands farmhands

label var mean_logpricerye "rye price"

line mean_farmhands year1 if year1>=1705 || line mean_logpricerye year1 if year1>=1705,  xline(1733 1742 1764 1788, lstyle(grid))

*Figure A2: market integration of grain and labour markets 1, 1705-1799

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen logwage = ln(norm_wage_rate)

*Load price data

merge m:1 manor year1 using "barley_prices_2.dta"

drop _merge

gen logpricebarley=ln(Pris_per_enhed)

gen FunenJutland=(region=="Jutland" | region=="Funen")

bysort year1: egen mean_wages =mean(logwage) if FunenJutland==1

bysort year1: egen mean_wages_2 =mean(logwage) if FunenJutland==0

bysort year1: egen mean_price =mean(logpricebarley) if FunenJutland==1

bysort year1: egen mean_price_2 =mean(logpricebarley) if FunenJutland==0

label var year1 year

label var mean_price "barley price - Jutland&Funen"

label var mean_price_2 "barley price - Zealand"

label var mean_wages "average wage - Jutland&Funen"

label var mean_wages_2 "average wage - Zealand"


line mean_wages year1 if year1 >=1705 || line mean_wages_2 year1 if year1 >=1705 || line mean_price year1 if year1 >=1705 || line mean_price_2 year1 if year1 >=1705

*Figure A3: market integration of grain and labour markets 2, 1705-1799

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen logwage = ln(norm_wage_rate)

*Load price data

merge m:1 manor year1 using "barley_prices_2.dta"

drop _merge

gen logpricebarley=ln(Pris_per_enhed)

bysort year1: egen sd_wage =sd(logwage)

bysort year1: egen sd_barley =sd(logpricebarley) 

bysort year1: egen mean_wages_3 =mean(logwage) 

bysort year1: egen mean_price_3 =mean(logpricebarley)


gen cv_wage=sd_wage/mean_wages_3

gen cv_barley=sd_barley/mean_price_3

label var cv_wage "coeff of variation for wages"

label var cv_barley "coeff of variation for barley prices"

line cv_wage year1 if year1>=1705 ||line cv_barley year1 if year1>=1705,  xline(1733 1742 1764 1788, lstyle(grid))

*Figure A4: Event study for the introduction of serfdom, coefficient on farmhands multiplied by year, males only

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen logwage = ln(norm_wage_rate)


*five year dummies

gen t1=(year1>1704 & year1 <1710)

gen t2=(year1>1709 & year1 <1715)

gen t3=(year1>1714 & year1 <1720)

gen t4=(year1>1719 & year1 <1725)

gen t5=(year1>1724 & year1 <1733)

gen t6=(year1>1732 & year1 <1735)

gen t7=(year1>1734 & year1 <1740)

gen t8=(year1>1739 & year1 <1745)

gen t9=(year1>1744 & year1 <1750)

gen t10=(year1>1749 & year1 <1755)

gen t11=(year1>1754 & year1 <1760)

gen t12=(year1>1759 & year1 <1765)

gen t13=(year1>1764 & year1 <1770)

gen t14=(year1>1769 & year1 <1775)

gen t15=(year1>1774 & year1 <1780)

gen t16=(year1>1779 & year1 <1785)

gen t17=(year1>1784 & year1 <1790)

gen t18=(year1>1789 & year1 <1795)

gen t19=(year1>1794 & year1 <1800)

gen unskilled1710=t2*unskilled

gen unskilled1715=t3*unskilled

gen unskilled1720=t4*unskilled

gen unskilled1725=t5*unskilled

gen unskilled1733=t6*unskilled

gen unskilled1735=t7*unskilled

gen unskilled1740=t8*unskilled

gen unskilled1745=t9*unskilled

gen unskilled1750=t10*unskilled

gen unskilled1755=t11*unskilled

gen unskilled1760=t12*unskilled

gen unskilled1765=t13*unskilled

gen unskilled1770=t14*unskilled

gen unskilled1775=t15*unskilled

gen unskilled1780=t16*unskilled

gen unskilled1785=t17*unskilled

gen unskilled1790=t18*unskilled

gen unskilled1795=t19*unskilled

gen women=(gender=="female")

xi: reg logwage unskilled1710 unskilled1715 unskilled1720 unskilled1725 unskilled1733 unskilled1735 unskilled1740 unskilled1745 unskilled1750 unskilled1755 unskilled1760 unskilled1765 unskilled1770 unskilled1775 unskilled1780 unskilled1785 unskilled1790 unskilled1795 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & women==0 & child==0, cluster(manor)

estimates store flex_serf

coefplot (flex_serf, label(event study)) , xsize(6.4) xtitle("Year") ytitle("Coefficients") omitted vertical msymbol(s) mfcolor(white) yline(0) rename(unskilled*=" ") keep(unskilled*)

*Figure A5: Fully flexible event study for the introduction of serfdom, coefficient on farmhands multiplied by year

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)
gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)
gen serdomunskilled=serfdom*unskilled
gen logwage = ln(norm_wage_rate)

*Table 1: full model - helps generate yeardummies

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

*Generate extra year dummies for loop

gen _Iyear1_1712=year1==1712

gen _Iyear1_1715=year1==1715

gen _Iyear1_1804=year1==1804

foreach VAR in unskilled {
	forvalues k=1705(1)1799{
		gen `VAR'_`k'= _Iyear1_`k'*`VAR'
	}
}

xi: reg logwage unskilled_* i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

estimates store flex_serf

coefplot (flex_serf, label(event study)) , xsize(6.4) xtitle("Year") ytitle("Coefficients") omitted vertical msymbol(s) mfcolor(white) yline(0) rename(unskilled_*=" ") keep(unskilled_*)

*Figure A6: Event study for the introduction of serfdom, coefficient on farmhands multiplied by year, controlling for bricklayer multiplied by year

clear

use "out2corr5.dta"

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen logwage = ln(norm_wage_rate)


*five year dummies

gen t1=(year1>1704 & year1 <1710)

gen t2=(year1>1709 & year1 <1715)

gen t3=(year1>1714 & year1 <1720)

gen t4=(year1>1719 & year1 <1725)

gen t5=(year1>1724 & year1 <1733)

gen t6=(year1>1732 & year1 <1735)

gen t7=(year1>1734 & year1 <1740)

gen t8=(year1>1739 & year1 <1745)

gen t9=(year1>1744 & year1 <1750)

gen t10=(year1>1749 & year1 <1755)

gen t11=(year1>1754 & year1 <1760)

gen t12=(year1>1759 & year1 <1765)

gen t13=(year1>1764 & year1 <1770)

gen t14=(year1>1769 & year1 <1775)

gen t15=(year1>1774 & year1 <1780)

gen t16=(year1>1779 & year1 <1785)

gen t17=(year1>1784 & year1 <1790)

gen t18=(year1>1789 & year1 <1795)

gen t19=(year1>1794 & year1 <1800)

gen unskilled1710=t2*unskilled

gen unskilled1715=t3*unskilled

gen unskilled1720=t4*unskilled

gen unskilled1725=t5*unskilled

gen unskilled1733=t6*unskilled

gen unskilled1735=t7*unskilled

gen unskilled1740=t8*unskilled

gen unskilled1745=t9*unskilled

gen unskilled1750=t10*unskilled

gen unskilled1755=t11*unskilled

gen unskilled1760=t12*unskilled

gen unskilled1765=t13*unskilled

gen unskilled1770=t14*unskilled

gen unskilled1775=t15*unskilled

gen unskilled1780=t16*unskilled

gen unskilled1785=t17*unskilled

gen unskilled1790=t18*unskilled

gen unskilled1795=t19*unskilled

gen bricklayer=(hisco==95120)

gen bricklayer1710=t2*bricklayer

gen bricklayer1715=t3*bricklayer

gen bricklayer1720=t4*bricklayer

gen bricklayer1725=t5*bricklayer

gen bricklayer1733=t6*bricklayer

gen bricklayer1735=t7*bricklayer

gen bricklayer1740=t8*bricklayer

gen bricklayer1745=t9*bricklayer

gen bricklayer1750=t10*bricklayer

gen bricklayer1755=t11*bricklayer

gen bricklayer1760=t12*bricklayer

gen bricklayer1765=t13*bricklayer

gen bricklayer1770=t14*bricklayer

gen bricklayer1775=t15*bricklayer

gen bricklayer1780=t16*bricklayer

gen bricklayer1785=t17*bricklayer

gen bricklayer1790=t18*bricklayer

gen bricklayer1795=t19*bricklayer


xi: reg logwage unskilled1710 unskilled1715 unskilled1720 unskilled1725 unskilled1733 unskilled1735 unskilled1740 unskilled1745 unskilled1750 unskilled1755 unskilled1760 unskilled1765 unskilled1770 unskilled1775 unskilled1780 unskilled1785 unskilled1790 unskilled1795 bricklayer1710 bricklayer1715 bricklayer1720 bricklayer1725 bricklayer1733 bricklayer1735 bricklayer1740 bricklayer1745 bricklayer1750 bricklayer1755 bricklayer1760 bricklayer1765 bricklayer1770 bricklayer1775 bricklayer1780 bricklayer1785 bricklayer1790 bricklayer1795 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

estimates store flex_serf

coefplot (flex_serf, label(event study)) , xsize(6.4) xtitle("Years") ytitle("Coefficients") omitted vertical msymbol(s) mfcolor(white) yline(0) rename(unskilled*=" ") keep(unskilled*)

*Figure A7: Event study for the introduction of serfdom, coefficient on farmhands multiplied by year, controlling for carpenter multiplied by year

clear

use "out2corr5.dta"

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen logwage = ln(norm_wage_rate)


*five year dummies

gen t1=(year1>1704 & year1 <1710)

gen t2=(year1>1709 & year1 <1715)

gen t3=(year1>1714 & year1 <1720)

gen t4=(year1>1719 & year1 <1725)

gen t5=(year1>1724 & year1 <1733)

gen t6=(year1>1732 & year1 <1735)

gen t7=(year1>1734 & year1 <1740)

gen t8=(year1>1739 & year1 <1745)

gen t9=(year1>1744 & year1 <1750)

gen t10=(year1>1749 & year1 <1755)

gen t11=(year1>1754 & year1 <1760)

gen t12=(year1>1759 & year1 <1765)

gen t13=(year1>1764 & year1 <1770)

gen t14=(year1>1769 & year1 <1775)

gen t15=(year1>1774 & year1 <1780)

gen t16=(year1>1779 & year1 <1785)

gen t17=(year1>1784 & year1 <1790)

gen t18=(year1>1789 & year1 <1795)

gen t19=(year1>1794 & year1 <1800)

gen unskilled1710=t2*unskilled

gen unskilled1715=t3*unskilled

gen unskilled1720=t4*unskilled

gen unskilled1725=t5*unskilled

gen unskilled1733=t6*unskilled

gen unskilled1735=t7*unskilled

gen unskilled1740=t8*unskilled

gen unskilled1745=t9*unskilled

gen unskilled1750=t10*unskilled

gen unskilled1755=t11*unskilled

gen unskilled1760=t12*unskilled

gen unskilled1765=t13*unskilled

gen unskilled1770=t14*unskilled

gen unskilled1775=t15*unskilled

gen unskilled1780=t16*unskilled

gen unskilled1785=t17*unskilled

gen unskilled1790=t18*unskilled

gen unskilled1795=t19*unskilled

gen carpenter=(hisco==95410)

gen carpenter1710=t2*carpenter

gen carpenter1715=t3*carpenter

gen carpenter1720=t4*carpenter

gen carpenter1725=t5*carpenter

gen carpenter1733=t6*carpenter

gen carpenter1735=t7*carpenter

gen carpenter1740=t8*carpenter

gen carpenter1745=t9*carpenter

gen carpenter1750=t10*carpenter

gen carpenter1755=t11*carpenter

gen carpenter1760=t12*carpenter

gen carpenter1765=t13*carpenter

gen carpenter1770=t14*carpenter

gen carpenter1775=t15*carpenter

gen carpenter1780=t16*carpenter

gen carpenter1785=t17*carpenter

gen carpenter1790=t18*carpenter

gen carpenter1795=t19*carpenter

xi: reg logwage unskilled1710 unskilled1715 unskilled1720 unskilled1725 unskilled1733 unskilled1735 unskilled1740 unskilled1745 unskilled1750 unskilled1755 unskilled1760 unskilled1765 unskilled1770 unskilled1775 unskilled1780 unskilled1785 unskilled1790 unskilled1795 carpenter1710 carpenter1715 carpenter1720 carpenter1725 carpenter1733 carpenter1735 carpenter1740 carpenter1745 carpenter1750 carpenter1755 carpenter1760 carpenter1765 carpenter1770 carpenter1775 carpenter1780 carpenter1785 carpenter1790 carpenter1795 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

estimates store flex_serf

coefplot (flex_serf, label(event study)) , xsize(6.4) xtitle("Years") ytitle("Coefficients") omitted vertical msymbol(s) mfcolor(white) yline(0) rename(unskilled*=" ") keep(unskilled*)


*Figure A8:Event study for the introduction of serfdom, coefficient on farmhands multiplied by year, controlling for head teacher multiplied by year

clear

use "out2corr5.dta"

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen logwage = ln(norm_wage_rate)


*five year dummies

gen t1=(year1>1704 & year1 <1710)

gen t2=(year1>1709 & year1 <1715)

gen t3=(year1>1714 & year1 <1720)

gen t4=(year1>1719 & year1 <1725)

gen t5=(year1>1724 & year1 <1733)

gen t6=(year1>1732 & year1 <1735)

gen t7=(year1>1734 & year1 <1740)

gen t8=(year1>1739 & year1 <1745)

gen t9=(year1>1744 & year1 <1750)

gen t10=(year1>1749 & year1 <1755)

gen t11=(year1>1754 & year1 <1760)

gen t12=(year1>1759 & year1 <1765)

gen t13=(year1>1764 & year1 <1770)

gen t14=(year1>1769 & year1 <1775)

gen t15=(year1>1774 & year1 <1780)

gen t16=(year1>1779 & year1 <1785)

gen t17=(year1>1784 & year1 <1790)

gen t18=(year1>1789 & year1 <1795)

gen t19=(year1>1794 & year1 <1800)

gen unskilled1710=t2*unskilled

gen unskilled1715=t3*unskilled

gen unskilled1720=t4*unskilled

gen unskilled1725=t5*unskilled

gen unskilled1733=t6*unskilled

gen unskilled1735=t7*unskilled

gen unskilled1740=t8*unskilled

gen unskilled1745=t9*unskilled

gen unskilled1750=t10*unskilled

gen unskilled1755=t11*unskilled

gen unskilled1760=t12*unskilled

gen unskilled1765=t13*unskilled

gen unskilled1770=t14*unskilled

gen unskilled1775=t15*unskilled

gen unskilled1780=t16*unskilled

gen unskilled1785=t17*unskilled

gen unskilled1790=t18*unskilled

gen unskilled1795=t19*unskilled

gen headteacher=(hisco==13940)

gen headteacher1710=t2*headteacher

gen headteacher1715=t3*headteacher

gen headteacher1720=t4*headteacher

gen headteacher1725=t5*headteacher

gen headteacher1733=t6*headteacher

gen headteacher1735=t7*headteacher

gen headteacher1740=t8*headteacher

gen headteacher1745=t9*headteacher

gen headteacher1750=t10*headteacher

gen headteacher1755=t11*headteacher

gen headteacher1760=t12*headteacher

gen headteacher1765=t13*headteacher

gen headteacher1770=t14*headteacher

gen headteacher1775=t15*headteacher

gen headteacher1780=t16*headteacher

gen headteacher1785=t17*headteacher

gen headteacher1790=t18*headteacher

gen headteacher1795=t19*headteacher

xi: reg logwage unskilled1710 unskilled1715 unskilled1720 unskilled1725 unskilled1733 unskilled1735 unskilled1740 unskilled1745 unskilled1750 unskilled1755 unskilled1760 unskilled1765 unskilled1770 unskilled1775 unskilled1780 unskilled1785 unskilled1790 unskilled1795 headteacher1710 headteacher1715 headteacher1720 headteacher1725 headteacher1733 headteacher1735 headteacher1740 headteacher1745 headteacher1750 headteacher1755 headteacher1760 headteacher1765 headteacher1770 headteacher1775 headteacher1780 headteacher1785 headteacher1790 headteacher1795 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

estimates store flex_serf

coefplot (flex_serf, label(event study)) , xsize(6.4) xtitle("Years") ytitle("Coefficients") omitted vertical msymbol(s) mfcolor(white) yline(0) rename(unskilled*=" ") keep(unskilled*)











