/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Monopsony power and wages: Evidence from the introduction of serfdom in Denmark  
by  Kathrin Gary, Peter Sandholt Jensen, Mats Olsson, Cristina Victoria Radu,
Battista Severgnini and Paul Sharp (2022)

The following do file replicates Tables reported both in the main text (p.54-61) and in the appendix. 

Before launching the file, please 

a) read the file readme.docx/readme.pdf contained in the zipped file

b) write your working directory in line 22 of this do file.

Launching this file, replicates all the results in Stata. As soon as the working directory is set, the code for each table can be run separately. 

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

*Packages needed to run this file: outreg2, ivreg210, acreg (acreg also requries ivreg2, hdfe and ranktest).Before running acreg we recommend to type acregpackcheck

*change working directory for location of data

cd "[insert directory with dta files]"

*Table 1: descriptive statistics

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen serdomunskilled=serfdom*unskilled

gen logwage = ln(norm_wage_rate)

gen women=(gender=="female")

gen FunenJutland=(region=="Jutland" | region=="Funen")

gen distmkt=9.89168538934437 if manor_name=="Giesegaard"
replace distmkt=18.0860822895706 if manor_name=="Bregentved"
replace distmkt=15.1256329846094 if manor_name=="Gisselfeld"
replace distmkt=1.93963992964699 if manor_name=="Herlufsholm"
replace distmkt=11.9291481570397 if manor_name=="Holsteinborg"
replace distmkt=14.1170665956053 if manor_name=="Fuirendal"
replace distmkt=3.60029125176941 if manor_name=="SoroAkademi"
replace distmkt=8.88528505886943 if manor_name=="Lovenborg"
replace distmkt=4.95122597001476 if manor_name=="Gauno"
replace distmkt=9.61762903605727 if manor_name=="Juellinge"
replace distmkt=4.99717207743065 if manor_name=="Taasinge"
replace distmkt=7.26788063065934 if manor_name=="Frederiksgave"
replace distmkt=17.0193324925298 if manor_name=="ErholmSondergade"
replace distmkt=22.9311697469675 if manor_name=="Frijsenborg"
replace distmkt=11.255873901928 if manor_name=="Stovringgard"
replace distmkt=17.4415588841169 if manor_name=="Lindenborg"
replace distmkt=10.7372899629484 if manor_name=="Odden"


*contruct the variable distcoast (in km)
gen distcoast=18.5899739432616 if manor_name=="Giesegaard"
replace distcoast=13.9559523207784 if manor_name=="Bregentved"
replace distcoast=13.1765193946474 if manor_name=="Gisselfeld"
replace distcoast=5.40140926852449 if manor_name=="Herlufsholm"
replace distcoast=2.71762420765539 if manor_name=="Holsteinborg"
replace distcoast=5.21276806750138 if manor_name=="Fuirendal"
replace distcoast=19.8368260887719 if manor_name=="SoroAkademi"
replace distcoast=6.93498133849996 if manor_name=="Lovenborg"
replace distcoast=0.833048737284951 if manor_name=="Gauno"
replace distcoast=5.5487019990304 if manor_name=="Juellinge"
replace distcoast=0.192423099770843 if manor_name=="Taasinge"
replace distcoast=1.66221327450295 if manor_name=="Frederiksgave"
replace distcoast=8.38634380618019 if manor_name=="ErholmSondergade"
replace distcoast=22.3398986515669 if manor_name=="Frijsenborg"
replace distcoast=1.20944673285807 if manor_name=="Stovringgard"
replace distcoast=14.391700773193 if manor_name=="Lindenborg"
replace distcoast=3.64392378506271 if manor_name=="Odden"

*contruct the variable distholst (in km)
gen distholst=127.041697400277 if manor_name=="Giesegaard"
replace distholst=118.169551249746 if manor_name=="Bregentved"
replace distholst=115.28602557765 if manor_name=="Gisselfeld"
replace distholst=104.603031828269 if manor_name=="Herlufsholm"
replace distholst=95.7971966961615 if manor_name=="Holsteinborg"
replace distholst=99.9605137195449 if manor_name=="Fuirendal"
replace distholst=121.680260770417 if manor_name=="SoroAkademi"
replace distholst=148.028003325048 if manor_name=="Lovenborg"
replace distholst=98.2518790437981 if manor_name=="Gauno"
replace distholst=125.576006908406 if manor_name=="Juellinge"
replace distholst=66.2299843790987 if manor_name=="Taasinge"
replace distholst=87.9881031476656 if manor_name=="Frederiksgave"
replace distholst=105.729512779942 if manor_name=="ErholmSondergade"
replace distholst=202.993311421295 if manor_name=="Frijsenborg"
replace distholst=227.94185556837 if manor_name=="Stovringgard"
replace distholst=273.551231227982 if manor_name=="Lindenborg"
replace distholst=343.436881120375 if manor_name=="Odden"

gen holstinteract=distholst*serdomunskilled
gen marketinteract=distmkt*serdomunskilled
gen seainteract=distcoast*serdomunskilled

gen holstinteract2=distholst*serfdom
gen marketinteract2=distmkt*serfdom
gen seainteract2=distcoast*serfdom

*Load price data

merge m:1 manor year1 using "barley_prices_2.dta"

drop _merge

merge m:1 manor year1 using "rye_prices_2.dta"

drop _merge

gen logpricebarley=ln(Pris_per_enhed)

gen logpricerye=ln(price_rye)

merge m:1 manor_name using "count_manors_for_match.dta"

drop _merge

* Herfindahl up to 40 km

gen Herfindahl10=num_manors10*(1/num_manors10)^2

gen Herfindahl20=num_manors20*(1/num_manors20)^2

gen Herfindahl30=num_manors30*(1/num_manors30)^2

gen Herfindahl40=num_manors40*(1/num_manors40)^2

gen year=year1
 
merge m:1 manor_name year using "manors_2.dta"
  
drop _merge
 
merge m:1 manor using "data_for_merge.dta"

gen dummy1775=year1>=1775

gen clover1775=DemesneClover1775Share*dummy1775

gen dummy1782=year1>=1782

gen koppelwirtschaft=mejeriab*dummy1782

gen clover_interact=serdomunskilled*clover1775

gen koppel_interact=serdomunskilled*koppelwirtschaft

gen hollanderi=0

replace hollanderi=1 if year1>=1776 & manor==13

replace hollanderi=1 if year1>=1773 & manor==5

replace hollanderi=1 if year1>=1771 & manor==10

replace hollanderi=1 if year1>=1782 & manor==16

replace hollanderi=1 if year1>=1767 & manor==11

gen hollanderi_interact=serdomunskilled*hollanderi

drop if logwage==.

sum logwage unskilled FunenJutland women child logpricebarley logpricerye distmkt distcoast distholst Herfindahl10 Herfindahl20 Herfindahl30 Herfindahl40 hollanderi koppelwirtschaft  clover1775 change_owner building other if year1>1704 & year1 <=1799





*Table 2: Main results

use "out2corr5.dta", clear


drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen unskilled1=(hisco==62105)

gen unskilled2=(hisco==99910)

gen unskilled3=(hisco==99920)

gen serdomunskilled=serfdom*unskilled

gen serdomunskilled1=serfdom*unskilled1

gen serdomunskilled2=serfdom*unskilled2

gen serdomunskilled3=serfdom*unskilled3



gen p1=(year1>1732 & year1 <1742)

gen p1unskilled=p1*unskilled

gen p2=(year1>=1742 & year1 <1764)

gen p2unskilled=p2*unskilled

gen p3=(year1>1763 & year1<=1787)

gen p3unskilled=p3*unskilled

gen p4=(year1>1787 & year1<1800)

gen p4unskilled=p4*unskilled

gen logwage = ln(norm_wage_rate)

gen vornedskab=(year1>=1717 & year1< 1733)

gen vornedskabinteract=vornedskab*unskilled

*Regional dummies

gen FunenJutland=(region=="Jutland" | region=="Funen")

gen Funen=(region=="Funen")

gen Jutland=(region=="Jutland")

*Column (1) 

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table2.txt", tstat bracket replace

gen _Iyear1_1712=year1==1712

gen _Iyear1_1715=year1==1715

gen _Iyear1_1804=year1==1804


foreach VAR in Funen {
	forvalues k=1705(1)1799{
		gen `VAR'_`k'= _Iyear1_`k'*`VAR'
	}
}

foreach VAR in Jutland {
	forvalues k=1705(1)1799{
		gen `VAR'_`k'= _Iyear1_`k'*`VAR'
	}
}

gen women=(gender=="female")

*inkind dummy

gen inkind= food_own_food_2

replace inkind = 0 if (inkind >= .)

replace inkind = 1 if (inkind > 0)

set matsize 10000

*Column (2)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & FunenJutland==1, cluster(manor)

outreg2 using "Table2.txt", tstat bracket append

*Column (3)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & FunenJutland==0, cluster(manor)

outreg2 using "Table2.txt", tstat bracket append

*Column (4)

xi: reg logwage serdomunskilled Funen_17* Jutland_17* i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table2.txt", tstat bracket append

*Column (5)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & women==0 & child==0, cluster(manor)

outreg2 using "Table2.txt", tstat bracket append

*Column (6)

xi: reg logwage serdomunskilled inkind i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table2.txt", tstat bracket append


*Table 3: Results with different contol groups 


use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen serdomunskilled=serfdom*unskilled

gen logwage = ln(norm_wage_rate)

gen women=(gender=="female")

gen bricklayer=(hisco==95120)

gen bricklayer_trend=bricklayer*year1

gen carpenter=(hisco==95410)

gen carpenter_trend=carpenter*year1

gen headteacher=(hisco==13940)

gen teacher_trend=headteacher*year1

gen unskilled4=(hisco==62120)

gen HISCLASS_1=0

replace HISCLASS_1=(hisco==14990|hisco==55240|hisco==56010|hisco==58940|hisco==59990|hisco==61115|hisco==62105|hisco==62120|hisco==62400|hisco==63110|hisco==74930|hisco==95945|hisco==99910|hisco==99920)

gen HISCLASS_1b=0

replace HISCLASS_1b=(hisco==14990|hisco==55240|hisco==56010|hisco==58940|hisco==59990|hisco==61115|hisco==62120|hisco==62400|hisco==63110|hisco==74930|hisco==95945)

gen HISCLASS_2=0

replace HISCLASS_2=(hisco==21990|hisco==37030|hisco==37040|hisco==39320|hisco==54010|hisco==62510|hisco==62740|hisco==63230|hisco==64100|hisco==71220|hisco==75430|hisco==81925|hisco==82020|hisco==89240|hisco==93120|hisco==94220|hisco==95160|hisco==95360|hisco==95910|hisco==96190|hisco==97152|hisco==98620)

gen lowskilled=HISCLASS_1+HISCLASS_2

gen lowskilledb=HISCLASS_1b+HISCLASS_2

*Column (1)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1 >1704 & lowskilled==1, cluster(manor)

outreg2 using "Table3.txt", tstat bracket replace

*Column (2)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1 >1704 & lowskilledb==0, cluster(manor)

outreg2 using "Table3.txt", tstat bracket append

*Column (3)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1 >1704 & lowskilled==1 & women==0 & child==0, cluster(manor)

outreg2 using "Table3.txt", tstat bracket append

*Column (4)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1 >1704 & lowskilledb==0 & women==0 & child==0, cluster(manor)

outreg2 using "Table3.txt", tstat bracket append

*Column (5)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & headteacher==0, cluster(manor)

outreg2 using "Table3.txt", tstat bracket append

*Column (6)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & carpenter==0, cluster(manor)

outreg2 using "Table3.txt", tstat bracket append

*Column (7)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if unskilled4==0 & year1>1704, cluster(manor)

outreg2 using "Table3.txt", tstat bracket append

*Column (8)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & bricklayer==0, cluster(manor)

outreg2 using "Table3.txt", tstat bracket append



* Table 4: Results with estate level control

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen serdomunskilled=serfdom*unskilled

gen logwage = ln(norm_wage_rate)

gen women=(gender=="female")

*contruct the variable distmkt (in km)
gen distmkt=9.89168538934437 if manor_name=="Giesegaard"
replace distmkt=18.0860822895706 if manor_name=="Bregentved"
replace distmkt=15.1256329846094 if manor_name=="Gisselfeld"
replace distmkt=1.93963992964699 if manor_name=="Herlufsholm"
replace distmkt=11.9291481570397 if manor_name=="Holsteinborg"
replace distmkt=14.1170665956053 if manor_name=="Fuirendal"
replace distmkt=3.60029125176941 if manor_name=="SoroAkademi"
replace distmkt=8.88528505886943 if manor_name=="Lovenborg"
replace distmkt=4.95122597001476 if manor_name=="Gauno"
replace distmkt=9.61762903605727 if manor_name=="Juellinge"
replace distmkt=4.99717207743065 if manor_name=="Taasinge"
replace distmkt=7.26788063065934 if manor_name=="Frederiksgave"
replace distmkt=17.0193324925298 if manor_name=="ErholmSondergade"
replace distmkt=22.9311697469675 if manor_name=="Frijsenborg"
replace distmkt=11.255873901928 if manor_name=="Stovringgard"
replace distmkt=17.4415588841169 if manor_name=="Lindenborg"
replace distmkt=10.7372899629484 if manor_name=="Odden"


*contruct the variable distcoast (in km)
gen distcoast=18.5899739432616 if manor_name=="Giesegaard"
replace distcoast=13.9559523207784 if manor_name=="Bregentved"
replace distcoast=13.1765193946474 if manor_name=="Gisselfeld"
replace distcoast=5.40140926852449 if manor_name=="Herlufsholm"
replace distcoast=2.71762420765539 if manor_name=="Holsteinborg"
replace distcoast=5.21276806750138 if manor_name=="Fuirendal"
replace distcoast=19.8368260887719 if manor_name=="SoroAkademi"
replace distcoast=6.93498133849996 if manor_name=="Lovenborg"
replace distcoast=0.833048737284951 if manor_name=="Gauno"
replace distcoast=5.5487019990304 if manor_name=="Juellinge"
replace distcoast=0.192423099770843 if manor_name=="Taasinge"
replace distcoast=1.66221327450295 if manor_name=="Frederiksgave"
replace distcoast=8.38634380618019 if manor_name=="ErholmSondergade"
replace distcoast=22.3398986515669 if manor_name=="Frijsenborg"
replace distcoast=1.20944673285807 if manor_name=="Stovringgard"
replace distcoast=14.391700773193 if manor_name=="Lindenborg"
replace distcoast=3.64392378506271 if manor_name=="Odden"

*contruct the variable distholst (in km)
gen distholst=127.041697400277 if manor_name=="Giesegaard"
replace distholst=118.169551249746 if manor_name=="Bregentved"
replace distholst=115.28602557765 if manor_name=="Gisselfeld"
replace distholst=104.603031828269 if manor_name=="Herlufsholm"
replace distholst=95.7971966961615 if manor_name=="Holsteinborg"
replace distholst=99.9605137195449 if manor_name=="Fuirendal"
replace distholst=121.680260770417 if manor_name=="SoroAkademi"
replace distholst=148.028003325048 if manor_name=="Lovenborg"
replace distholst=98.2518790437981 if manor_name=="Gauno"
replace distholst=125.576006908406 if manor_name=="Juellinge"
replace distholst=66.2299843790987 if manor_name=="Taasinge"
replace distholst=87.9881031476656 if manor_name=="Frederiksgave"
replace distholst=105.729512779942 if manor_name=="ErholmSondergade"
replace distholst=202.993311421295 if manor_name=="Frijsenborg"
replace distholst=227.94185556837 if manor_name=="Stovringgard"
replace distholst=273.551231227982 if manor_name=="Lindenborg"
replace distholst=343.436881120375 if manor_name=="Odden"

gen holstinteract=distholst*serdomunskilled
gen marketinteract=distmkt*serdomunskilled
gen seainteract=distcoast*serdomunskilled

gen holstinteract2=distholst*serfdom
gen marketinteract2=distmkt*serfdom
gen seainteract2=distcoast*serfdom

*Load price data

merge m:1 manor year1 using "barley_prices_2.dta"

drop _merge

merge m:1 manor year1 using "rye_prices_2.dta"

drop _merge

gen logpricebarley=ln(Pris_per_enhed)

gen logpricebarley_l=ln(lagbarley_prices)
 
gen logpricerye=ln(price_rye)

gen logpricerye_1=ln(lagprice_rye)

gen barleysample=1

replace barleysample=0 if logpricebarley==.

gen ryesample=1

replace ryesample=0 if logpricerye==.

* Column (1)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & barleysample==1, cluster(manor)

outreg2 using "Table4.txt", tstat bracket replace

* Column (2)

xi: reg logwage serdomunskilled logpricebarley i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table4.txt", tstat bracket append

* Column (3)

xi: reg logwage serdomunskilled logpricerye i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table4.txt", tstat bracket append

* Column (4)

xi: reg logwage serdomunskilled marketinteract2 distmkt i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table4.txt", tstat bracket append

* Column (5)

xi: reg logwage serdomunskilled seainteract2 distcoast i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table4.txt", tstat bracket append

* Column (6)

xi: reg logwage serdomunskilled holstinteract2 distholst i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table4.txt", tstat bracket append

* Column (7)

xi: reg logwage serdomunskilled marketinteract2 seainteract2 holstinteract2 distmkt distcoast distholst i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table4.txt", tstat bracket append

gen winter=0

replace winter=1 if season=="v"

gen winterserfdom=winter*serfdom

gen winter_interact=winter*serdomunskilled

* Column (8)

xi: reg logwage serdomunskilled winterserfdom i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table4.txt", tstat bracket append

*Table 5: Results with contrl for Herfindahl indices at different distances

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen serdomunskilled=serfdom*unskilled

gen logwage = ln(norm_wage_rate)

merge m:1 manor_name using "count_manors_for_match.dta"

drop _merge

* Herfindahl up to 40 km

gen Herfindahl10=num_manors10*(1/num_manors10)^2

gen Herfindahl20=num_manors20*(1/num_manors20)^2

gen Herfindahl30=num_manors30*(1/num_manors30)^2

gen Herfindahl40=num_manors40*(1/num_manors40)^2

*interactions

gen Herfindahl_interact10_2=Herfindahl10*serfdom

gen Herfindahl_interact20_2=Herfindahl20*serfdom

gen Herfindahl_interact30_2=Herfindahl30*serfdom

gen Herfindahl_interact40_2=Herfindahl40*serfdom


gen Herfindahl_interact10=Herfindahl10*serdomunskilled

gen Herfindahl_interact20=Herfindahl20*serdomunskilled

gen Herfindahl_interact30=Herfindahl30*serdomunskilled

gen Herfindahl_interact40=Herfindahl40*serdomunskilled


*Column (1)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table5.txt", tstat bracket replace

*Column (2)

xi: reg logwage serdomunskilled Herfindahl10 Herfindahl_interact10_2 Herfindahl_interact10 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table5.txt", tstat bracket append

*Column (3)

xi: reg logwage serdomunskilled Herfindahl20 Herfindahl_interact20_2 Herfindahl_interact20 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table5.txt", tstat bracket append

*Column (4)

xi: reg logwage serdomunskilled Herfindahl30 Herfindahl_interact30_2 Herfindahl_interact30 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table5.txt", tstat bracket append

*Column (5)

xi: reg logwage serdomunskilled Herfindahl40 Herfindahl_interact40_2 Herfindahl_interact40 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table5.txt", tstat bracket append

*Table 6: Results with estate level innovation controls

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen serdomunskilled=serfdom*unskilled

gen logwage = ln(norm_wage_rate)

 gen year=year1
 
 merge m:1 manor_name year using "manors_2.dta"
  
 drop _merge
 
merge m:1 manor using "data_for_merge.dta"

gen dummy1775=year1>=1775

gen clover1775=DemesneClover1775Share*dummy1775

gen dummy1782=year1>=1782

gen koppelwirtschaft=mejeriab*dummy1782

gen clover_interact=serdomunskilled*clover1775

gen koppel_interact=serdomunskilled*koppelwirtschaft

gen hollanderi=0

replace hollanderi=1 if year1>=1776 & manor==13

replace hollanderi=1 if year1>=1773 & manor==5

replace hollanderi=1 if year1>=1771 & manor==10

replace hollanderi=1 if year1>=1782 & manor==16

replace hollanderi=1 if year1>=1767 & manor==11

gen hollanderi_interact=serdomunskilled*hollanderi

*Column (1)

xi: reg logwage serdomunskilled koppelwirtschaft koppel_interact i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table6.txt", tstat bracket replace

*Column (2)

xi: reg logwage serdomunskilled hollanderi hollanderi_interact i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table6.txt", tstat bracket append

**Column (3)

xi: reg logwage serdomunskilled clover1775 clover_interact i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table6.txt", tstat bracket append

*Column (4)

xi: reg logwage serdomunskilled change_owner building other i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table6.txt", tstat bracket append

*Column (5)

xi: reg logwage serdomunskilled clover1775 clover_interact hollanderi hollanderi_interact change_owner building other i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)
  
outreg2 using "Table6.txt", tstat bracket append

*Table 7: Results with estate fixed effects

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen serdomunskilled=serfdom*unskilled

gen unskilled1=(hisco==62105)

gen unskilled2=(hisco==99910)

gen unskilled3=(hisco==99920)

gen serdomunskilled1=serfdom*unskilled1

gen serdomunskilled2=serfdom*unskilled2

gen serdomunskilled3=serfdom*unskilled3

gen p1=(year1>1732 & year1 <1742)

gen p1unskilled=p1*unskilled

gen p2=(year1>=1742 & year1 <1764)

gen p2unskilled=p2*unskilled

gen p3=(year1>1763 & year1<=1787)

gen p3unskilled=p3*unskilled

gen p4=(year1>1787 & year1<1800)

gen p4unskilled=p4*unskilled

gen logwage = ln(norm_wage_rate)

*Column (1)

xi: reg logwage p1unskilled p2unskilled p3unskilled p4unskilled i.manor i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table7.txt", tstat bracket replace

*Column (2)

xi: reg logwage serdomunskilled i.manor i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table7.txt", tstat bracket append

*Column (3)

xi: reg logwage serdomunskilled1 serdomunskilled2 serdomunskilled3 i.manor i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "Table7.txt", tstat bracket append

*Column (4)

xi: reg logwage serdomunskilled1 i.manor i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & unskilled2==0 & unskilled3==0, cluster(manor)

outreg2 using "Table7.txt", tstat bracket append

*Column (5)

xi: reg logwage serdomunskilled2 i.manor i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & unskilled1==0 & unskilled3==0, cluster(manor)

outreg2 using "Table7.txt", tstat bracket append

*Column (6)

xi: reg logwage serdomunskilled3 i.manor i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & unskilled1==0 & unskilled2==0, cluster(manor)

outreg2 using "Table7.txt", tstat bracket append

gen p1unskilled_1=p1*unskilled1
gen p1unskilled_2=p1*unskilled2
gen p1unskilled_3=p1*unskilled3
gen p2unskilled_1=p2*unskilled1
gen p2unskilled_2=p2*unskilled2
gen p2unskilled_3=p2*unskilled3
gen p3unskilled_1=p3*unskilled1
gen p3unskilled_2=p3*unskilled2
gen p3unskilled_3=p3*unskilled3
gen p4unskilled_1=p4*unskilled1
gen p4unskilled_2=p4*unskilled2
gen p4unskilled_3=p4*unskilled3

*Column (7)

xi: reg logwage p1unskilled_1 p2unskilled_1 p3unskilled_1 p4unskilled_1 i.manor i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & unskilled2==0 & unskilled3==0, cluster(manor)

outreg2 using "Table7.txt", tstat bracket append

*Column (8)

xi: reg logwage p1unskilled_2 p2unskilled_2 p3unskilled_2 p4unskilled_2 i.manor i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & unskilled1==0 & unskilled3==0, cluster(manor)

outreg2 using "Table7.txt", tstat bracket append

*Column (9)

xi: reg logwage p1unskilled_3 p2unskilled_3 p3unskilled_3 p4unskilled_3 i.manor i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & unskilled1==0 & unskilled2==0, cluster(manor)

outreg2 using "Table7.txt", tstat bracket append

*Table 8: The effect of the introduction of Serfdom on Wages using the Scanian control group

use "Scania.dta", clear

gen Denmark=0

replace Denmark=1 if region =="Funen"|region=="Jutland"|region=="Zealand"

drop if region=="hasnone"

gen serfdom=year>=1733

gen serfdom_DK=serfdom*Denmark

gen logwage=ln(wagerate)

gen wagerate2=wagerate/96

gen logwage2=ln(wagerate2)

*Skilling measures

gen wagerateDK_2= Denmark*wagerate

gen wagerateSC_2=(1-Denmark)*wagerate*16*4*6 

gen wagerate3=wagerateDK_2+wagerateSC_2


merge m:1 year Denmark using "EXRdata.dta"

gen wagerateDK= Denmark*wagerate/96

gen wagerateSC=exr*(1-Denmark)*wagerate/100

gen wagerateCR=wagerateDK+wagerateSC

gen wagerateSC2=(1-Denmark)*wagerate

gen wagerateCR2=wagerateDK+wagerateSC2

gen rwage=wagerateCR2/price_normal

gen logwageCR=ln(wagerateCR)

gen logwageCR2=ln(rwage)

gen logwage3=ln(wagerate3)

gen unskilled1=(HISCO==62105)

gen unskilled2=(HISCO==99910)

gen unskilled3=(HISCO==99920)

gen unskilled=(HISCO==62105 | HISCO==99910 | HISCO==99920)


*Column (1)
xi: reg logwage serfdom_DK i.year i.gender i.region if year> 1704 & year <1800 & unskilled==1, cluster(placename)

outreg2 using "Table8.txt", tstat bracket replace

*Column (2)
xi: reg logwageCR serfdom_DK i.year i.gender i.region if year> 1704 & year <1800 & unskilled==1, cluster(placename)

outreg2 using "Table8.txt", tstat bracket append

*Column (3)
xi: reg logwageCR2 serfdom_DK i.year i.gender i.region if year> 1704 & year <1800 & unskilled==1, cluster(placename)

outreg2 using "Table8.txt", tstat bracket append

gen Sample1=0

replace Sample1=1 if region =="Funen"|region=="Jutland"|region=="Scania"


*Column (4)
xi: reg logwage serfdom_DK i.year i.gender i.region if year> 1704 & year <1800 & unskilled==1 & Sample1==1, cluster(placename)

outreg2 using "Table8.txt", tstat bracket append


*Column (5)
xi: reg logwageCR serfdom_DK i.year i.gender i.region if year> 1704 & year <1800 & unskilled==1 & Sample1==1, cluster(placename)

outreg2 using "Table8.txt", tstat bracket append


*Column (6)
xi: reg logwageCR2 serfdom_DK i.year i.gender i.region if year> 1704 & year <1800 & unskilled==1 & Sample1==1, cluster(placename)

outreg2 using "Table8.txt", tstat bracket append

gen Sample2=0

replace Sample2=1 if region =="Zealand"|region=="Scania"


*Column (7)
xi: reg logwage serfdom_DK i.year i.gender i.region if year> 1704 & year <1800 & unskilled==1 & Sample2==1, cluster(placename)

outreg2 using "Table8.txt", tstat bracket append

*Column (8)
xi: reg logwageCR serfdom_DK i.year i.gender i.region if year> 1704 & year <1800 & unskilled==1 & Sample2==1, cluster(placename)

outreg2 using "Table8.txt", tstat bracket append

*Column (9)
xi: reg logwageCR2 serfdom_DK i.year i.gender i.region if year> 1704 & year <1800 & unskilled==1 & Sample2==1, cluster(placename)

outreg2 using "Table8.txt", tstat bracket append

*Table 9: The effect of serfdom on probability that new apprentices were recruited from the countryside

use "apprentice_data.dta", clear

gen serfdom1=Year >=1733

gen serfdomd1=(Year >=1733 & Year< 1742)

gen serfdomd2=(Year >=1742 & Year< 1764)

gen serfdomd3=(Year >=1764 & Year< 1788)

gen serfdomd4=(Year >=1788)

*Column (1)

xi: reg Country serfdom1 i.Lav, robust cluster(Lav)

outreg2 using "Table9.txt", bdec(3) tdec(3) tstat    bracket replace

*Column (2)

xi: reg Country serfdomd* i.Lav, robust cluster(Lav)

outreg2 using "Table9.txt", bdec(3) tdec(3) tstat    bracket append


*Appendix Tables

*Tables A1-A3 were not constructed in STATA (literature overview and list of time periods from source listed in paper)

*Table A4 is constructed by combining the following information:

clear

use "out2corr5.dta"

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen serdomunskilled=serfdom*unskilled

gen logwage = ln(norm_wage_rate)

gen women=(gender=="female")

gen FunenJutland=(region=="Jutland" | region=="Funen")

*Compute the distribution of wage observations from 1705-1799 (any occupation)

tab region if year1>1704

tab region if year1>1704 & year1 <= 1741

tab region if year1>1741 & year1 <= 1763

tab region if year1>1764 & year1 <= 1787

tab region if year1>1787 & year1 <= 1799

*Compute the distribution of farmhands (denoted unskilled). The distribution out of all observations is computed by dividing by the total number of observations for all occupations.

tab region if year1>1704 & unskilled==1

*Table A5 is constructed from tabulating hisco codes combined with the occupational names from this classification for occupations with more than 100 observations:
/*Labourer	99910
Day labourer	99920
Bricklayer	95120
Painter	93120
Carpenter	95410
Thatcher	95360
Farm labourer	62105
Dairy worker	62510
Gardener	62740
livestock worker	62400
Joiner	95420
Stone mason	95140
Farm servant	62120
Teacher	13940
farm supervisor	22520
Coachman	98620
servant at home	54010
Gamekeeper	64960
Forest Supervisor	63220
Paviour	95160
Washerwoman	56010
barn bailiff	21990
stone cutter	82020
Logger	63110
Animal-Drawn Vehicle Driver (Road)	95910
Cook	53100
stone splitter	71220
Guard	58940
Housekeeper	22430*/

clear

use "out2corr5.dta"

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

tab hisco if year1>1704

*Table A6: Alternative flexible estimations with regular five year periods

use "out2corr5.dta", clear

gen p5=(year1>=1800)

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen logwage = ln(norm_wage_rate)


*five year dummies

gen t1=(year1>1704 & year1 <1710)

gen t2=(year1>1709 & year1 <1715)

gen t3=(year1>1714 & year1 <1720)

gen t4=(year1>1719 & year1 <1725)

gen t5=(year1>1724 & year1 <1730)

gen t6=(year1>1729 & year1 <1735)

gen t7=(year1>1734 & year1 <1740)

gen t8=(year1>1739 & year1 <1745)

gen t9=(year1>1744 & year1 <1750)

gen t10=(year1>1749 & year1 <1755)

gen t11=(year1>1754 & year1 <1760)

gen t12=(year1>1759 & year1 <1765)

gen t13=(year1>1764 & year1 <1770)

gen t14=(year1>1769 & year1 <1775)

gen t15=(year1>1774 & year1 <1780)

gen t16=(year1>1779 & year1 <1785)

gen t17=(year1>1784 & year1 <1790)

gen t18=(year1>1789 & year1 <1795)

gen t19=(year1>1794 & year1 <1800)

gen unskilled1710=t2*unskilled

gen unskilled1715=t3*unskilled

gen unskilled1720=t4*unskilled

gen unskilled1725=t5*unskilled

gen unskilled1730=t6*unskilled

gen unskilled1735=t7*unskilled

gen unskilled1740=t8*unskilled

gen unskilled1745=t9*unskilled

gen unskilled1750=t10*unskilled

gen unskilled1755=t11*unskilled

gen unskilled1760=t12*unskilled

gen unskilled1765=t13*unskilled

gen unskilled1770=t14*unskilled

gen unskilled1775=t15*unskilled

gen unskilled1780=t16*unskilled

gen unskilled1785=t17*unskilled

gen unskilled1790=t18*unskilled

gen unskilled1795=t19*unskilled


xi: reg logwage unskilled1710 unskilled1715 unskilled1720 unskilled1725 unskilled1730 unskilled1735 unskilled1740 unskilled1745 unskilled1750 unskilled1755 unskilled1760 unskilled1765 unskilled1770 unskilled1775 unskilled1780 unskilled1785 unskilled1790 unskilled1795 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "TableA6.txt", tstat bracket replace

*Table A7:  Results with different time periods and 6 estates with data both before and after serfdom

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen serdomunskilled=serfdom*unskilled

gen logwage = ln(norm_wage_rate)

gen women=(gender=="female")

*Column (1)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & year1 < 1742, cluster(manor)

outreg2 using "TableA7.txt", tstat bracket replace

*Column (2)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & year1 < 1764, cluster(manor)

outreg2 using "TableA7.txt", tstat bracket append

*Column (3)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & year1 < 1788, cluster(manor)

outreg2 using "TableA7.txt", tstat bracket append

*Column (4)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "TableA7.txt", tstat bracket append

gen sixmanors=(manor==1) | (manor==3) | (manor==10) | (manor==11) | (manor==13) | (manor==18)

*Column (5)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1 >1704 & year1 < 1742 & sixmanors==1, cluster(manor)

outreg2 using "TableA7.txt", tstat bracket append

*Column (6)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1 >1704 & year1 < 1764 & sixmanors==1, cluster(manor)

outreg2 using "TableA7.txt", tstat bracket append

*Column (7)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1 >1704 & year1 < 1788 & sixmanors==1, cluster(manor)

outreg2 using "TableA7.txt", tstat bracket append

*Column (8)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1 >1704 & sixmanors==1, cluster(manor)

outreg2 using "TableA7.txt", tstat bracket append

* Table A8: Effects of using alternative treatment measure (farm labourer) and using men only

use "out2corr5.dta", clear

drop if year1>1799

tab hisco if year1>1704

clear

use "out2corr5.dta"

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen serdomunskilled=serfdom*unskilled

gen unskilled1=(hisco==62105)

gen unskilled2=(hisco==99910)

gen unskilled3=(hisco==99920)

gen serdomunskilled1=serfdom*unskilled1

gen serdomunskilled2=serfdom*unskilled2

gen serdomunskilled3=serfdom*unskilled3

gen logwage = ln(norm_wage_rate)

gen women=(gender=="female")

*Column (1)

xi: reg logwage serdomunskilled1 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & year1 < 1742 & women==0 & child==0, cluster(manor)

outreg2 using "TableA8.txt", tstat bracket replace

*Column (2)

xi: reg logwage serdomunskilled1 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & year1 < 1764 & women==0 & child==0, cluster(manor)

outreg2 using "TableA8.txt", tstat bracket append

*Column (3)

xi: reg logwage serdomunskilled1 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & year1 < 1788 & women==0 & child==0, cluster(manor)

outreg2 using "TableA8.txt", tstat bracket append

*Column (4)

xi: reg logwage serdomunskilled1 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & women==0 & child==0, cluster(manor)

outreg2 using "TableA8.txt", tstat bracket append

gen sixmanors=(manor==1) | (manor==3) | (manor==10) | (manor==11) | (manor==13) | (manor==18)

*Column (5)

xi: reg logwage serdomunskilled1 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1 >1704 & year1 < 1742 & sixmanors==1 & women==0 & child==0, cluster(manor)

outreg2 using "TableA8.txt", tstat bracket append

*Column (6)

xi: reg logwage serdomunskilled1 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1 >1704 & year1 < 1764 & sixmanors==1 & women==0 & child==0, cluster(manor)

outreg2 using "TableA8.txt", tstat bracket append

*Column (7)

xi: reg logwage serdomunskilled1 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1 >1704 & year1 < 1788 & sixmanors==1 & women==0 & child==0, cluster(manor)

outreg2 using "TableA8.txt", tstat bracket append

*Column (8)

xi: reg logwage serdomunskilled1 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1 >1704 & sixmanors==1 & women==0 & child==0, cluster(manor)

outreg2 using "TableA8.txt", tstat bracket append

*Table A9: Results with additional robustness checks

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen serdomunskilled=serfdom*unskilled

gen unskilled1=(hisco==62105)

gen unskilled2=(hisco==99910)

gen unskilled3=(hisco==99920)

gen serdomunskilled1=serfdom*unskilled1

gen serdomunskilled2=serfdom*unskilled2

gen serdomunskilled3=serfdom*unskilled3

gen p1=(year1>1732 & year1 <1742)

gen p1unskilled=p1*unskilled

gen p2=(year1>=1742 & year1 <1764)

gen p2unskilled=p2*unskilled

gen p3=(year1>1763 & year1<=1787)

gen p3unskilled=p3*unskilled

gen p4=(year1>1787 & year1<1800)

gen p4unskilled=p4*unskilled

gen vornedskab=(year1>=1717 & year1< 1733)

gen vornedskabinteract=vornedskab*unskilled

gen logwage = ln(norm_wage_rate)

*Column (1)

xi: reg logwage p1unskilled p2unskilled p3unskilled p4unskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "TableA9.txt", tstat bracket replace

*Column (2)

xi: reg logwage p1unskilled p2unskilled p3unskilled p4unskilled vornedskabinteract i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

outreg2 using "TableA9.txt", tstat bracket append

*Column (3)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(hisco)

outreg2 using "TableA9.txt", tstat bracket append

*Column (4)

xi: ivreg210 logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(hisco manor)

outreg2 using "TableA9.txt", tstat bracket append

*Column (5)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend, cluster(manor)

outreg2 using "TableA9.txt", tstat bracket append

*Column (6)

xi: reg logwage serdomunskilled1 serdomunskilled2 serdomunskilled3 i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1> 1704, cluster(manor)

outreg2 using "TableA9.txt", tstat bracket append

*Table A10: Effects on other occupations

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen serdomunskilled=serfdom*unskilled

gen logwage = ln(norm_wage_rate)

gen women=(gender=="female")

gen bricklayer=(hisco==95120)

gen bricklayer_trend=bricklayer*year1

gen carpenter=(hisco==95410)

gen carpenter_trend=carpenter*year1

gen headteacher=(hisco==13940)

gen teacher_trend=headteacher*year1

gen bricklayerserfdom=bricklayer*serfdom

gen carpenterserfdom=carpenter*serfdom

gen teacherserfdom=headteacher*serfdom


*Column (1)
xi: reg logwage teacherserfdom i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)
outreg2 using "TableA10.txt", tstat bracket replace


*Column (2)
xi: reg logwage bricklayerserfdom i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)
outreg2 using "TableA10.txt", tstat bracket append


*Column (3)
xi: reg logwage carpenterserfdom i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)
outreg2 using "TableA10.txt", tstat bracket append


*Column (4)
xi: reg logwage serdomunskilled teacherserfdom i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)
outreg2 using "TableA10.txt", tstat bracket append

*Column (5)
xi: reg logwage serdomunskilled bricklayerserfdom i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)
outreg2 using "TableA10.txt", tstat bracket append


*Column (6)
xi: reg logwage serdomunskilled carpenterserfdom i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)
outreg2 using "TableA10.txt", tstat bracket append

*Column (7)
xi: reg logwage serdomunskilled bricklayer_trend carpenter_trend teacher_trend i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)
outreg2 using "TableA10.txt", tstat bracket append



*Tabel A11: Results from the pseudo panel

use "pseudopanel.dta", clear

*Column (1)
 
xi: xtreg logwage serdomunskilled  dreg* dchild* dseason*   i.ayear if ayear>1704, fe vce(cluster group)
outreg2 using "TableA11.txt", bdec(3) tdec(3)    tstat bracket replace

*Column (2)

xi: xtreg logwage serdomunskilled  dreg* dchild* dseason*   dmester*  i.ayear if ayear>1704, fe vce(cluster group)
outreg2 using "TableA11.txt", bdec(3) tdec(3) tstat    bracket append

*Column (3)

xi: xtreg logwage serdomunskilled  dreg* dchild* dseason*   dmester* dmanor* i.ayear if ayear>1704, fe vce(cluster group)
outreg2 using "TableA11.txt", bdec(3) tdec(3) tstat    bracket append

*Column (4)

xi: xtreg logwage serdomunskilled  dreg* dchild* dseason* dhisco*  dmester* dmanor* i.ayear if ayear>1704, fe vce(cluster group)
outreg2 using "TableA11.txt", bdec(3) tdec(3) tstat    bracket append

*Tabel A12: Results from the pseuod panal for koppelwirtschaft adoption 

*Column (1)

xi: xtreg hollanderi serdomunskilled  dreg* dchild* dseason*   i.ayear if ayear>1704, fe vce(cluster group)
outreg2 using "TableA12.txt", bdec(3) tdec(3) tstat    bracket replace

*Column (2)

xi: xtreg hollanderi serdomunskilled  dreg* dchild* dseason*   dmester*  i.ayear if ayear>1704, fe vce(cluster group)
outreg2 using "TableA12.txt", bdec(3) tdec(3) tstat    bracket append

*Column (3)

xi: xtreg hollanderi serdomunskilled  dreg* dchild* dseason*   dmester* dmanor* i.ayear if ayear>1704, fe vce(cluster group)
outreg2 using "TableA12.txt", bdec(3) tdec(3) tstat    bracket append

*Column (4)

xi: xtreg hollanderi serdomunskilled  dreg* dchild* dseason* dhisco*  dmester* dmanor* i.ayear if ayear>1704, fe vce(cluster group)
outreg2 using "TableA12.txt", bdec(3) tdec(3) tstat    bracket append


*Table A13: Main results with standard errors correcting for spatial correlation of up to 40 kilometers.

use "out2corr5.dta", clear

drop if year1>1799

gen serfdom=(year1>=1733 & year1 < 1800)

gen unskilled=(hisco==62105 | hisco==99910 | hisco==99920)

gen unskilled1=(hisco==62105)

gen unskilled2=(hisco==99910)

gen unskilled3=(hisco==99920)

gen serdomunskilled=serfdom*unskilled

gen serdomunskilled1=serfdom*unskilled1

gen serdomunskilled2=serfdom*unskilled2

gen serdomunskilled3=serfdom*unskilled3

gen p1=(year1>1732 & year1 <1742)

gen p1unskilled=p1*unskilled

gen p2=(year1>=1742 & year1 <1764)

gen p2unskilled=p2*unskilled

gen p3=(year1>1763 & year1<=1787)

gen p3unskilled=p3*unskilled

gen p4=(year1>1787 & year1<1800)

gen p4unskilled=p4*unskilled

gen logwage = ln(norm_wage_rate)

gen vornedskab=(year1>=1717 & year1< 1733)

gen vornedskabinteract=vornedskab*unskilled

*Regional dummies

gen FunenJutland=(region=="Jutland" | region=="Funen")

gen Funen=(region=="Funen")

gen Jutland=(region=="Jutland")

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

gen _Iyear1_1712=year1==1712

gen _Iyear1_1715=year1==1715

gen _Iyear1_1804=year1==1804


foreach VAR in Funen {
	forvalues k=1705(1)1799{
		gen `VAR'_`k'= _Iyear1_`k'*`VAR'
	}
}

foreach VAR in Jutland {
	forvalues k=1705(1)1799{
		gen `VAR'_`k'= _Iyear1_`k'*`VAR'
	}
}

gen all=1

foreach VAR in all {
	forvalues k=1705(1)1799{
		gen `VAR'_`k'= _Iyear1_`k'*`VAR'
	}
}

gen women=(gender=="female")

*inkind dummy

gen inkind= food_own_food_2

replace inkind = 0 if (inkind >= .)

replace inkind = 1 if (inkind > 0)

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

*filling logitude and latitude when there are missing values
bysort manor_name: egen maxlatitude=max(Latitudine)
bysort manor_name: egen maxlongitude=max(Longitudine)

replace Latitudine=maxlatitude if Latitudine==.
replace Longitudine=maxlongitude if Longitudine==.

preserve
keep if year1>1704
drop if missing(Latitudine)==1
drop if missing(Longitudine)==1
for @ in any logwage serdomunskilled region gender child year1 season : drop if missing(@)==1
for @ in any hisco mester_svend : drop if missing(@)==1

*Column (1) - Note: you need to run all commands from the last preserve to the restore after the acreg command to use the correct samples.

xi: acreg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend ,  latitude(Latitudine) longitude(Longitudine) dist(40)  spatial
restore
outreg2 using "TableA13.txt", tstat bracket replace

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & FunenJutland==1, cluster(manor)

preserve
keep if year1>1704 & FunenJutland==1
drop if missing(Latitudine)==1
drop if missing(Longitudine)==1
for @ in any logwage serdomunskilled region gender child year1 season : drop if missing(@)==1
for @ in any hisco mester_svend : drop if missing(@)==1

*Column (2) - Note: you need to run all commands from the last preserve to the restore after the acreg command to use the correct samples.

xi: acreg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend ,  latitude(Latitudine) longitude(Longitudine) dist(40)  spatial
restore

outreg2 using "TableA13.txt", tstat bracket append

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & FunenJutland==0, cluster(manor)

preserve
keep if year1>1704 & FunenJutland==0
drop if missing(Latitudine)==1
drop if missing(Longitudine)==1
for @ in any logwage serdomunskilled region gender child year1 season : drop if missing(@)==1
for @ in any hisco mester_svend : drop if missing(@)==1

*Column (3) - Note: you need to run all commands from the last preserve to the restore after the acreg command to use the correct samples.

xi: acreg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend ,  latitude(Latitudine) longitude(Longitudine) dist(40)  spatial
restore


outreg2 using "TableA13.txt", tstat bracket append


xi: reg logwage serdomunskilled Funen_17* Jutland_17* i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

preserve
keep if year1>1704 
drop if missing(Latitudine)==1
drop if missing(Longitudine)==1
for @ in any logwage serdomunskilled region gender child year1 season : drop if missing(@)==1
for @ in any hisco mester_svend : drop if missing(@)==1

*Column (4) - Note: you need to run all commands from the last preserve to the restore after the acreg command to use the correct samples.

xi: acreg logwage serdomunskilled Jutland_1706 Jutland_1709 Jutland_1710 Jutland_1713 Jutland_1716 Jutland_1717 Jutland_1718 Jutland_1719 Funen_1726 Funen_1732 Funen_1733 Funen_1736 Funen_1737 Funen_1738 Funen_1739 Funen_1740 Funen_1741 Funen_1742 Funen_1746 Funen_1747 Funen_1748 Funen_1749 Funen_175* Funen_176* Funen_177* Funen_178* Funen_179* Jutland_172* Jutland_173* Jutland_1740 Jutland_1741 Jutland_1742 Jutland_1743 Jutland_1745 Jutland_1746 Jutland_1747 Jutland_1748 Jutland_1749 Jutland_175* Jutland_176* Jutland_177* Jutland_178* Jutland_179* i.region i.gender i.child all_1706 all_1707 all_1708 all_1710 all_1711 all_1717 all_1718 all_1719 all_1720 all_1722 all_1724 all_1725 all_1726 all_1727 all_1728 all_1729 all_173* all_174* all_175* all_176* all_177* all_178* all_179* i.hisco i.season i.mester_svend,  latitude(Latitudine) longitude(Longitudine) dist(40) spatial
restore

outreg2 using "TableA13.txt", tstat bracket append

xi: reg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704 & women==0 & child==0, cluster(manor)

preserve
keep if year1>1704 & women==0 & child==0
drop if missing(Latitudine)==1
drop if missing(Longitudine)==1
for @ in any logwage serdomunskilled region gender child year1 season : drop if missing(@)==1
for @ in any hisco mester_svend : drop if missing(@)==1

*Column (5) - Note: you need to run all commands from the last preserve to the restore after the acreg command to use the correct samples.

xi: acreg logwage serdomunskilled i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend ,  latitude(Latitudine) longitude(Longitudine) dist(40)  spatial
restore

outreg2 using "TableA13.txt", tstat bracket append

xi: reg logwage serdomunskilled inkind i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend if year1>1704, cluster(manor)

preserve
keep if year1>1704 
drop if missing(Latitudine)==1
drop if missing(Longitudine)==1
for @ in any logwage serdomunskilled inkind region gender child year1 season : drop if missing(@)==1
for @ in any hisco mester_svend : drop if missing(@)==1

*Column (6)

xi: acreg logwage serdomunskilled inkind i.region i.gender i.child i.year1 i.season i.hisco i.mester_svend ,  latitude(Latitudine) longitude(Longitudine) dist(40)  spatial
restore


outreg2 using "TableA13.txt", tstat bracket append





